@@ -30,14 +30,37 @@ class PiezoelectricBuilder(Builder):
         self.tasks.key = "task_id"
         self.piezoelectric.key = "material_id"
 
-        super().__init__(sources=[materials, tasks], targets=[piezoelectric], **kwargs)
+        super().__init__(
+            sources=[materials, tasks], targets=[piezoelectric], **kwargs,
+        )
 
-    def prechunk(self, number_splits: int):
+    def prechunk(self, number_splits: int):  # pragma: no cover
         """
         Prechunk method to perform chunking by the key field
         """
         q = dict(self.query)
 
+        # Ensure no centrosymmetry
+        q.update(
+            {
+                "symmetry.point_group": {
+                    "$nin": [
+                        "-1",
+                        "2/m",
+                        "mmm",
+                        "4/m",
+                        "4/mmm",
+                        "-3",
+                        "-3m",
+                        "6/m",
+                        "6/mmm",
+                        "m-3",
+                        "m-3m",
+                    ]
+                }
+            }
+        )
+
         keys = self.piezoelectric.newer_in(self.materials, criteria=q, exhaustive=True)
 
         N = ceil(len(keys) / number_splits)
@@ -166,11 +189,10 @@ class PiezoelectricBuilder(Builder):
                     "last_updated",
                     "input.is_hubbard",
                     "orig_inputs.kpoints",
-                    "orig_inputs.poscar",
+                    "orig_inputs.poscar.structure",
                     "input.parameters",
                     "output.piezo_tensor",
                     "output.piezo_ionic_tensor",
-                    "output.structure",
                 ],
                 criteria={self.tasks.key: str(task_id)},
             )
