@@ -152,7 +152,7 @@ class SummaryBuilder(Builder):
 
             yield data
 
-    def prechunk(self, number_splits: int):
+    def prechunk(self, number_splits: int):  # pragma: no cover
         """
         Prechunk method to perform chunking by the key field
         """
